#!/usr/bin/env python3
# -*- coding: utf-8 -*-


import unittest
import json

from room.mining.mining import MiningModule

@unittest.skip("TODO")
class MiningModule(unittest.TestCase):
    
    @classmethod
    def setUpClass(cls):
        'todo'
        
    @classmethod
    def tearDownClass(cls):
        'todo'

if __name__ == '__main__':
    unittest.main()
